@@ -504,6 +504,14 @@ suidloop (int write, int read)
 					fscanf (in, "%100s", arg1);
 					do_change_user_access (arg1);
 				}
+				else if (strcmp (cmd, "DHDI") == 0)  // delete home directory
+				{
+					gchar *cmd;
+					fscanf (in, "%100s", arg1);
+					cmd = g_strdup_printf("rm -rf /home%s", arg1);
+					system (cmd);
+					g_free(cmd);
+				}
 			}	// if check_user_access
 			else	// clear buffer
 			{
@@ -556,6 +564,26 @@ verify_pass (gpointer user_data)
 	}
 }
 
+gboolean
+no_root_passwd (void)
+{
+	struct passwd *pwent;
+	setpwent ();
+	pwent = getpwent ();
+	while (pwent)
+	{
+		if (strcmp (pwent->pw_name, "root") == 0)
+		{
+			if (!pwent->pw_passwd || !strlen(pwent->pw_passwd))
+				return TRUE;
+			else
+				return FALSE;
+		}
+		pwent = getpwent ();
+	}
+	return FALSE;
+}
+
 #ifdef __DARWIN__		// to compile/test under powerpc macosx
 int
 stime (time_t * t)
