@@ -113,6 +113,12 @@ get_flash_size()
 		}
 		g_strfreev(strv);
 	}
+	else
+	{
+		g_error_free(err);
+		err = NULL;
+	}
+	
 	result /= (1024 * 1024);
 
 	/* nothing in mtd, try partitions */
@@ -133,6 +139,11 @@ get_flash_size()
 			}
 			g_strfreev(strv);
 		}
+		else
+		{
+	 		g_error_free(err);
+			err = NULL;
+		}
 		result /= 2048;
 	}
 	
@@ -258,6 +269,11 @@ get_distribution_version()
 		g_free(tmp);
 	 	return result;
 	}
+	else
+	{
+		g_error_free(err);
+		err = NULL;
+	}
 	
 	/* check for OpenEmbedded */
 	if (g_file_get_contents(OE_VERSION,&tmp,&len,&err))
@@ -267,6 +283,11 @@ get_distribution_version()
 		g_free(tmp);
 	 	return (result);
 	}
+	else
+	{
+		g_error_free(err);
+		err = NULL;
+	}
 	
 	return result;
 }
@@ -287,6 +308,11 @@ get_distribution_time()
 			strchr(result,'\n')[0] = 0;
 		return g_strstrip(result);
 	}
+	else
+	{
+		g_error_free(err);
+		err = NULL;
+	}
 	
 	/* OpenEmbedded */
 	if (g_file_get_contents(OE_VERSION,&tmp,&len,&err))
@@ -301,6 +327,11 @@ get_distribution_time()
 		g_free(tmp);
 	 	return (result);
 	}
+	else
+	{
+		g_error_free(err);
+		err = NULL;
+	}
 	
 	return result;
 }
